# -*- coding: utf-8 -*-
from genshi.builder import tag

from trac.wiki.macros import WikiMacroBase

class ColorMacro(WikiMacroBase):
    """
    This macro allows you to add color.

    Author: David Roussel

    Usage:
    {{{
      [[Color( background-color, color , text )]]
    }}}
    or
    {{{
      [[Color( color , text )]]
    }}}
    Where: 
    color::
      is a color keyword or hex color number recognised by your browser
    text::
      any text or html you like

    Example:
    {{{
      [[Color(red,This has a red background)]]
      [[Color(blue, green,This has a blue background and green text)]]
    }}}
    """

    def expand_macro(self, formatter, name, args):
        args = tuple(args.split(","))
        if len(args) == 2 :
            return tag.span(args[1], style="background-color:%s;padding: 0.1ex 0.4em;" % args[0:1])
        else:
            return tag.span(args[2], style="background-color:%s;padding: 0.1ex 0.4em;color:%s;" % args[0:2])
